Learn R Programming

fastnet (version 1.0.0)

degree.hist: Histogram of the degree distribution of a network

Description

Plot the histogram of all degrees of a network.

Usage

degree.hist(g, breaks = 100)

Arguments

g

The input network.

breaks

A single number giving the number of cells for the histogram.

Value

A .gif plot.

Details

Plot the histogram of all degrees of a network.

Examples

Run this code
# NOT RUN {
x <-  net.erdos.renyi.gnp(1000, 0.05)
degree.hist(x)
# }

Run the code above in your browser using DataLab