Learn R Programming

fastnet (version 1.0.0)

metric.cluster.mean: Mean Local Clustering Coefficient

Description

Calculate the average local clustering coefficient of a graph.

Usage

metric.cluster.mean(g)

Arguments

g

The input network.

Value

A real constant.

Details

The local clustering coefficient of a node is the ratio of the triangles connected to the node and the triples centered on the node.metric.cluster.mean() calculates the (estimated) average clustering coefficient for all nodes in graph g with a justified error.

References

Wasserman, Stanley, and Katherine Faust. Social network analysis: Methods and applications. Vol. 8. Cambridge university press, 1994.

Examples

Run this code
# NOT RUN {
x <-  net.erdos.renyi.gnp(n = 1000, ncores = 3, p =  0.06)
metric.cluster.mean(x) 
# }

Run the code above in your browser using DataLab