metric.cluster.median: Median Local Clustering Coefficient
Description
Calculate the median local clustering coefficient of a graph.
Usage
metric.cluster.median(g)
Arguments
g
The input network.
Value
A real constant.
Details
The local clustering coefficient of a node is the ratio of the triangles connected to the node and the triples centered on the node.metric.cluster.median() calculates the (estimated) median clustering coefficient for all nodes in graph g with a justified error.
References
Wasserman, Stanley, and Katherine Faust. Social network analysis: Methods and applications. Vol. 8. Cambridge university press, 1994.