Learn R Programming

fastnet (version 1.0.0)

metric.degree.sd: Standard Deviation of Degree Distribution

Description

Calculate the standard deviation of all degrees of a network.

Usage

metric.degree.sd(g)

Arguments

g

The input network.

Value

A real constant.

Details

The standard deviation of all degrees of a network.

Examples

Run this code
# NOT RUN {
metric.degree.sd(x)
# }

Run the code above in your browser using DataLab