Learn R Programming

fastnet (version 1.0.0)

metric.distance.meanecc: Mean Eccentricity

Description

Calculate the mean eccentricity of a graph.

Usage

metric.distance.meanecc(g, p)

Arguments

g

The input network.

p

The sampling probability.

Value

A real constant.

Details

The mean eccentricities of all nodes in graph g. Calculates the (estimated) mean eccentricity of graph g with a justified error.

References

West, Douglas Brent. Introduction to graph theory. Vol. 2. Upper Saddle River: Prentice Hall, 2001.

Examples

Run this code
# NOT RUN {
x <-  net.erdos.renyi.gnp(1000, 0.01)
metric.distance.meanecc(x, 0.01)
# }

Run the code above in your browser using DataLab