Learn R Programming

fastnet (version 1.0.0)

net.barabasi.albert: Barabasi-Albert Scale-free Graph

Description

Simulate a scale-free network using a preferential attachment mechanism (Barabasi and Albert, 1999)

Usage

net.barabasi.albert(n, m, ncores = detectCores(), d = FALSE)

Arguments

n

Number of nodes of the network.

m

Number of nodes to which a new node connects at each iteration.

ncores

Number of cores, by default detectCores() from parallel.

d

A logical value determining whether the generated network is a directed or undirected (default) network.

Value

A list containing the nodes of the network and their respective neighbors.

Details

Starting with m nodes, the preferential attachment mechaism adds one node and m edges in each step. The edges will be placed with one end on the newly-added node and the other end on the existing nodes, according to probabilities that associate with their current degrees.

References

Barabasi, A.- L. and Albert R. 1999. Emergence of scaling in random networks. Science, 286 509-512.

Examples

Run this code
# NOT RUN {
x <- net.barabasi.albert(1000, 20) # using default ncores 
# }

Run the code above in your browser using DataLab