Learn R Programming

fastnet (version 1.0.0)

net.cluster.affiliation: Generate a cluster-affiliation graph

Description

Generate a cluster-affiliation graph.

Usage

net.cluster.affiliation(
  DEG,
  community_affiliation_alpha,
  community_affiliation_lambda,
  community_affiliation_min,
  community_size_alpha,
  community_size_lambda,
  community_size_min
)

Arguments

DEG

Degree sequence.

community_affiliation_alpha

First scaling parameter of the membership distribution.

community_affiliation_lambda

Second scaling parameter of the membership distribution.

community_affiliation_min

Minimal membership.

community_size_alpha

First scaling parameter of the cluster-size distribution.

community_size_lambda

Second scaling parameter of the cluster-size distribution.

community_size_min

Minimal size of a cluster.

Value

A list containing the nodes of the network and their respective neighbors.

Details

The generated network has multiple (overlapping) densely-connected clusters.

References

Dong X, Castro L, Shaikh N (2020). <U+201C>fastnet: An R Package for Fast Simulation and Analysis of Large-Scale Social Networks.<U+201D> Journal of Statistical Software, 96(7), 1-23. doi:10.18637/jss.v096.i07 (URL: https://doi.org/10.18637/jss.v096.i07)

Examples

Run this code
# NOT RUN {
DEG <- sample(seq(5,15),100, replace=TRUE)
x <- net.cluster.affiliation(DEG,
                             community_affiliation_alpha=1.5,
                             community_affiliation_lambda=10,
                             community_affiliation_min=1,
                             community_size_alpha=2.5,
                             community_size_lambda=40,
                             community_size_min=3)
# }

Run the code above in your browser using DataLab