Learn R Programming

fastnet (version 1.0.0)

net.erdos.renyi.gnm: Directed / Undirected Erdos-Renyi \(G(n,m)\) network using a fix edge size.

Description

Simulate a random network with n nodes and m edges, according to Erdos and Renyi (1959).

Usage

net.erdos.renyi.gnm(n, m, ncores = detectCores(), d = TRUE)

Arguments

n

Number of nodes of the network.

m

Number of edges of the network.

ncores

Number of cores, by default detectCores() from parallel.

d

A logical value determining whether is a network directed (default) or indirected.

Value

A list containing the nodes of the network and their respective neighbors.

Details

In this (simplest) random network, m edges are formed at random among n nodes. When d = TRUE is a directed network.

References

Erdos, P. and Renyi, A., On random graphs, Publicationes Mathematicae 6, 290-297 (1959).

Examples

Run this code
# NOT RUN {
x <- net.erdos.renyi.gnm(1000, 100) 
# }

Run the code above in your browser using DataLab