Learn R Programming

fastnet (version 1.0.0)

net.holme.kim: Holme-Kim Network

Description

Simulate a scale-free network with relatively high clustering, comparing to B-A networks (Holme and Kim, 1999).

Usage

net.holme.kim(n, m, pt)

Arguments

n

Number of nodes of the network.

m

Number of nodes to which a new node connects at each iteration.

pt

Triad formation probability after each preferential attachment mechanism.

Value

A list containing the nodes of the network and their respective neighbors.

Details

The Holme-Kim network model is a simple extension of B-A model. It adds an additional step, called "Triad formation", with the probability pt that compensates the low clustering in B-A networks.

References

Holme, Petter, and Beom Jun Kim. "Growing scale-free networks with tunable clustering."Physical review E65, no. 2 (2002): 026107.

Examples

Run this code
# NOT RUN {
x <- net.holme.kim (1000, 20, 0.1)
# }

Run the code above in your browser using DataLab