Learn R Programming

fastnet (version 1.0.0)

net.rewired.caveman: Rewired (Connected) Caveman Network

Description

Simulate a rewired caveman network of m cliques of size k, and with a link rewiring probability p.

Usage

net.rewired.caveman(nc, m, p, seed = 99)

Arguments

nc

Number of cliques (or caves) in the network.

m

Number of nodes per clique.

p

Link rewiring probability.

seed

A random seed.

Value

A list containing the nodes of the network and their respective neighbors.

Details

The rewired caveman network is built on the corresponding regular caveman network with m cliques of size k. Then the links in this caveman network are rewired with probability p.

References

Watts, D. J. Networks, Dynamics, and the Small-World Phenomenon. Amer. J. Soc. 105, 493-527, 1999.

Examples

Run this code
# NOT RUN {
x <- net.rewired.caveman(50, 20, 0.0005)
# }

Run the code above in your browser using DataLab