Learn R Programming

fastnet (version 1.0.0)

net.ring.lattice: k - regular ring lattice

Description

Simulate a network with a k -regular ring lattice structure.

Usage

net.ring.lattice(n, k)

Arguments

n

Number of nodes in the network.

k

Number of edges per node.

Value

A list containing the nodes of the network and their respective neighbors.

Details

The n nodes are placed on a circle and each node is connected to the nearest k neighbors.

References

Duncan J Watts and Steven H Strogatz: Collective dynamics of 'small world' networks, Nature 393, 440-442, 1998.

Examples

Run this code
# NOT RUN {
x <- net.ring.lattice(1000, 10)
# }

Run the code above in your browser using DataLab