powered by
Plot the histogram of all degrees of a network.
degree.hist(g, breaks = 100)
The input network.
A single number giving the number of cells for the histogram.
A .gif plot.
# NOT RUN { x <- net.erdos.renyi.gnp(1000, 0.05) degree.hist(x) # }
Run the code above in your browser using DataLab