metric.cluster.global: Global Clustering Coefficient
Description
Calculate the global clustering coefficient of a graph.
Usage
metric.cluster.global(g)
Arguments
g
The input network.
Value
A real constant.
Details
The global clustering coefficient measures the ratio of (closed) triples versus the total number of all possible triples in network g. metric.cluster.global() calculates the global clustering coefficient of g.
References
Wasserman, Stanley, and Katherine Faust. Social network analysis: Methods and applications. Vol. 8. Cambridge university press, 1994.