metric.cluster.mean: Mean Local Clustering Coefficient
Description
Calculate the average local clustering coefficient of a graph.
Usage
metric.cluster.mean(g)
Arguments
g
The input network.
Value
A real constant.
Details
The local clustering coefficient of a node is the ratio of the triangles connected to the node and the triples centered on the node.metric.cluster.mean() calculates the (estimated) average clustering coefficient for all nodes in graph g with a justified error.
References
Wasserman, Stanley, and Katherine Faust. Social network analysis: Methods and applications. Vol. 8. Cambridge university press, 1994.