powered by
Calculate the standard deviation of all degrees of a network.
metric.degree.sd(g)
The input network.
A real constant.
The standard deviation of all degrees of a network.
# NOT RUN { metric.degree.sd(x) # }
Run the code above in your browser using DataLab