Calculate the (estimated) median eccentricity of a graph.
Usage
metric.distance.medianecc(g, p)
Arguments
g
The input network.
p
The sampling probability.
Value
A real constant.
Details
Is the median eccentricities of all nodes in graph g.
metric.distance.medianecc calculates the (estimated) median eccentricity of graph g with a justified error.
References
West, Douglas Brent. Introduction to graph theory. Vol. 2. Upper Saddle River: Prentice hall, 2001.