powered by
Simulate a random network with n nodes and m edges, according to Erdos and Renyi (1959).
net.erdos.renyi.gnm(n, m, ncores = detectCores(), d = TRUE)
Number of nodes of the network.
Number of edges of the network.
Number of cores, by default detectCores() from parallel.
detectCores()
parallel
A logical value determining whether is a network directed (default) or indirected.
A list containing the nodes of the network and their respective neighbors.
In this (simplest) random network, m edges are formed at random among n nodes. When d = TRUE is a directed network.
d = TRUE
Erdos, P. and Renyi, A., On random graphs, Publicationes Mathematicae 6, 290-297 (1959).
# NOT RUN { x <- net.erdos.renyi.gnm(1000, 100) # }
Run the code above in your browser using DataLab