powered by
Simulate a random network with n nodes and a link connecting probability of p, according to Edos and Renyi (1959).
net.erdos.renyi.gnp(n, p, ncores = detectCores(), d = TRUE)
Number of nodes of the network.
Connecting probability.
Number of cores, by default detectCores() from parallel.
detectCores()
parallel
A logical value determining whether is a network directed (default) or indirected.
A list containing the nodes of the network and their respective neighbors.
In this (simplest) random network, each edge is formed at random with a constant probability. When d = TRUE is a directed network.
d = TRUE
Erdos, P. and Renyi, A., On random graphs, Publicationes Mathematicae 6, 290-297 (1959).
# NOT RUN { x <- net.erdos.renyi.gnp(1000, 0.01) # }
Run the code above in your browser using DataLab