powered by
Simulate a network with a k -regular ring lattice structure.
net.ring.lattice(n, k)
Number of nodes in the network.
Number of edges per node.
A list containing the nodes of the network and their respective neighbors.
The n nodes are placed on a circle and each node is connected to the nearest k neighbors.
Duncan J Watts and Steven H Strogatz: Collective dynamics of 'small world' networks, Nature 393, 440-442, 1998.
# NOT RUN { x <- net.ring.lattice(1000, 10) # }
Run the code above in your browser using DataLab