Simulate a small-world network according to the model of Watts and Strogatz (1998).
Usage
net.watts.strogatz(n, k, re)
Arguments
n
The number of the nodes in the network (or lattice).
k
Number of edges per node.
re
Rewiring probability.
Value
A list containing the nodes of the network and their respective neighbors.
Details
The formation of Watts-Strogatz network starts with a ring lattice with n nodes and k edges per node, then each edge is rewired at random with probability re.
References
Duncan J. Watts and Steven H. Strogatz: Collective dynamics of 'small world' networks, Nature 393, 440-442, 1998.